<template>
  <!-- 采集任务弹框 -->
  <div>
    <el-dialog
      :title="title + '任务'"
      :visible="visible"
      :before-close="handleClose"
      width="65%"
    >
      <el-form
        ref="formInfo"
        :rules="rules"
        :model="params"
        label-width="150px"
      >
        <el-row>
          <el-col :span="11">
            <el-form-item label="任务名称：" prop="taskName">
              <el-input
                maxlength="256"
                clearable
                placeholder="请输入任务名称"
                v-model="params.taskName"
              ></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="11">
            <el-form-item label="任务类型：" prop="taskType">
              <el-select
                style="width: 100%"
                placeholder="请选择任务类型"
                clearable
                v-model="params.taskType"
                popper-class="scorll"
              >
                <el-option
                  v-for="item in taskTypes"
                  :key="item.id"
                  :label="item.label"
                  :value="item.value"
                >
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="19">
            <el-form-item label="任务执行类：" prop="taskClass">
              <el-input
                maxlength="256"
                clearable
                style="width: 100%"
                placeholder="请输入任务执行类"
                v-model="params.taskClass"
              ></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button type="primary" plain @click="verification">
              验证任务执行类
            </el-button>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="9">
            <el-form-item inline="true" label="任务频率：" prop="taskRate">
              <el-input
                clearable
                placeholder="请输入调用频率"
                v-model="params.taskRate"
              ></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="6" style="margin-left: -150px">
            <el-form-item>
              <el-select clearable v-model="params.taskRateUnit">
                <el-option
                  v-for="item in taskRateUnits"
                  :key="item.id"
                  :label="item.label"
                  :value="item.label"
                ></el-option>
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        
        <el-row>
          <el-col :span="22">
            <el-form-item label="任务说明：" prop="taskMemo">
              <el-input
                maxlength="500"
                type="textarea"
                :autosize="{minRows: 4}"
                placeholder="请输入内容"
                v-model="params.taskMemo"
              >
              </el-input>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>

      <span slot="footer" class="dialog-footer">
        <el-tooltip
          content="请暂停任务后修改"
          :disabled="
            this.title === '新增' || this.params.taskStatus === 'NONE'
              ? true
              : this.params.taskStatus === 'PAUSED'
              ? true
              : false
          "
          placement="top"
        >
          <span>
            <el-button
              type="primary"
              @click="handleSave"
              :disabled="this.params.taskStatus === 'NORMAL' ? true : false"
              >保 存</el-button
            >
          </span>
        </el-tooltip>
        <el-button @click="handleClose" style="margin-left: 10px"
          >取 消</el-button
        >
      </span>
    </el-dialog>
  </div>
</template>

<script>
import req from '@/request.js'
import collection from '@/api/device/collection.js'
export default {
  name: 'TaskFormDialog',
  data() {
    return {
      visible: false,
      title: '新增',
      params: {
        taskName: '', //任务名称
        taskType: undefined, //任务类别
        taskClass: '', //任务执行类
        taskRate: null, //任务调用频率
        taskRateUnit: 'm', //任务调用频率单位(m:分钟，h:小时，d:天，w:周，M:月，Y：年)
        sourceCode: '', //数据源
        sourceTable: '', //源表名
        taskMemo: '', //任务说明
        taskStatus: '',
      },
      dataSources: [], //数据源列表
      sourceTables: [], //源表名列表
      taskTypes: [
        {value: 1, label: '定时任务'},
        {value: 2, label: '非定时任务'},
      ], //任务类别列表
      taskRateUnits: [
        {value: 0, label: 'm'},
        {value: 1, label: 'h'},
        {value: 2, label: 'd'},
        {value: 3, label: 'w'},
        {value: 4, label: 'M'},
        {value: 5, label: 'Y'},
      ], //任务调用频率单位列表
      rules: {
        taskName: [
          {
            required: true,
            message: '请输入任务名称',
            trigger: 'blur',
          },
        ],
        taskType: [
          {
            required: true,
            message: '请选择任务类别',
            trigger: 'blur',
          },
        ],
        taskClass: [
          {
            required: true,
            message: '请输入任务执行类',
            trigger: 'blur',
          },
        ],
        taskRate: [
          {
            required: true,
            message: '请输入任务调用频率',
            trigger: 'blur',
          },
        ],
      },
    }
  },
  methods: {
    add() {
      this.visible = true
      this.getDataSources()
    },
    edit(row) {
      this.title = '修改'
      this.getDataSources()
      this.getDetail(row.id)
    },
    // 关闭新增窗口
    handleClose() {
      this.params = {
        taskName: '', //任务名称
        taskType: undefined, //任务类别
        taskClass: '', //任务执行类
        taskRate: null, //任务调用频率
        taskRateUnit: 'm', //任务调用频率单位(m:分钟，h:小时，d:天，w:周，M:月，Y：年)
        sourceCode: '', //数据源
        sourceTable: '', //源表名
        taskMemo: '', //任务说明
        taskStatus: '',
      }
      this.title = '新增'
      this.$refs.formInfo.resetFields()
      this.visible = false
    },
    //获取源表名
    remoteMethod(query) {
      let obj = {
        dsalias: this.params.sourceCode,
        isTable: '1',
        objName: query,
      }
      this.sourceTables = []
      collection.sourceTables(obj, (res) => {
        this.sourceTables = res
      })
    },
    // 根据ID查询
    getDetail(id) {
      collection.detailId(id, (res) => {
        this.params = res
        this.visible = true
      })
    },
    // 保存新增任务
    handleSave() {
      this.$refs.formInfo.validate((valid) => {
        console.log(valid)
        if (valid) {
          if (this.title === '新增') {
            let arr = JSON.parse(JSON.stringify(this.params))
            collection.addSave(this.params, (response) => {
              if (response.state) {
                this.$notify({
                  type: 'success',
                  message: '新增成功',
                  duration: 2000,
                })
                this.handleClose()
                this.$emit('reload')
              }
            })
          }
          if (this.title === '修改') {
            collection.upData(this.params, (response) => {
              if (response.state) {
                this.$notify({
                  type: 'success',
                  message: '修改成功',
                  duration: 2000,
                })
                this.handleClose()
                this.$emit('reload')
              }
            })
          }
        }else{
          this.$notify({
            type: 'warning',
            message: "请完善表单信息！",
            duration: 2000,
          })
        }
      })
    },
    // 验证任务执行
    verification() {
      let className = this.params.taskClass
      if (!className) {
        this.$message({
          message: '任务执行类为空！',
          type: 'warning',
          duration: 2000,
        })
        return
      }
      collection.verification(className, (res) => {
        console.log(res)
        if (res.state) {
          this.$message({
            message: '验证成功',
            type: 'success',
            duration: 2000,
          })
        }
      })
    },
    // 获取数据源
    getDataSources() {
      let portal = window.context.portal
      req.get(portal + '/sys/sysDataSource/v1/getDataSources').then((res) => {
        this.dataSources = res.data
      })
    },
  },
}
</script>

<style lang="scss">
.scorll {
  .el-scrollbar__wrap {
    overflow: scroll;
    height: 100%;
  }
}
</style>
